@@ -8,8 +8,7 @@ from dyatel.mixins.internal_utils import calculate_coordinate_to_click
 
 
 class WebElement(CoreElement):
-    def __init__(self, locator: str, locator_type: str = '', name: str = '',
-                 parent: Union[WebElement, Any] = None, wait: bool = False):
+    def __init__(self, locator: str, locator_type: str, name: str, parent: Union[WebElement, Any], wait: bool):
         """
         Initializing of web element with selenium driver
 
@@ -33,13 +32,16 @@ class WebElement(CoreElement):
         selenium_elements = self._find_elements(self._get_base())
         return self._get_all_elements(selenium_elements, WebElement)
 
-    def hover(self) -> WebElement:
+    def hover(self, silent: bool = False) -> WebElement:
         """
         Hover over current element
 
+        :param silent: erase log
         :return: self
         """
-        self.log(f'Hover over "{self.name}"')
+        if not silent:
+            self.log(f'Hover over "{self.name}"')
+
         self._action_chains\
             .move_to_element(self.element)\
             .move_by_offset(1, 1)\
@@ -57,6 +59,9 @@ class WebElement(CoreElement):
         """
         self.log(f'Hover outside from "{self.name}"')
 
+        if not self.is_fully_visible(silent=True):
+            self.scroll_into_view()
+
         x, y = calculate_coordinate_to_click(self, x, y)
         self._action_chains\
             .move_to_location(x, y)\
@@ -73,16 +78,28 @@ class WebElement(CoreElement):
         """
         self.log(f'Click outside from "{self.name}"')
 
+        if not self.is_fully_visible(silent=True):
+            self.scroll_into_view()
+
         x, y = calculate_coordinate_to_click(self, x, y)
 
         self.driver_wrapper.click_by_coordinates(x=x, y=y, silent=True)
         return self
 
-    def get_rect(self) -> dict:
+    def click_into_center(self, silent: bool = False) -> WebElement:
         """
-        A dictionary with the size and location of the element.
+        Click into the center of element
 
-        :return: dict ~ {'y': 0, 'x': 0, 'width': 0, 'height': 0}
+        :param silent: erase log message
+        :return: self
         """
-        sorted_items: list = sorted(self.element.rect.items(), reverse=True)
-        return dict(sorted_items)
+        if not self.is_fully_visible(silent=True):
+            self.scroll_into_view()
+
+        x, y = calculate_coordinate_to_click(self, 0, 0)
+
+        if not silent:
+            self.log(f'Click into the center (x: {x}, y: {y}) for "{self.name}"')
+
+        self.driver_wrapper.click_by_coordinates(x=x, y=y, silent=True)
+        return self
